@@ -2,11 +2,12 @@
 
 from csvitself import csv2csv
 from fixed import fixed2csv
+from js import json2csv
 from xls import xls2csv
 
-SUPPORTED_FORMATS = ['fixed', 'xls', 'csv']
+SUPPORTED_FORMATS = ['fixed', 'xls', 'csv', 'json']
 
-def convert(f, format, schema=None, **kwargs):
+def convert(f, format, schema=None, key=None, **kwargs):
     """
     Convert a file of a specified format to CSV.
     """
@@ -23,6 +24,8 @@ def convert(f, format, schema=None, **kwargs):
         return fixed2csv(f, schema, **kwargs)
     elif format == 'xls':
         return xls2csv(f, **kwargs)
+    elif format == 'json':
+        return json2csv(f, key, **kwargs)
     elif format == 'csv':
         return csv2csv(f, **kwargs)
     else:
@@ -42,6 +45,8 @@ def guess_format(filename):
 
     if extension == 'xls':
         return extension
+    elif extension in ['json', 'js']:
+        return 'json' 
     elif extension == 'csv':
         return extension
     elif extension == 'fixed':
